@@ -48,13 +48,6 @@ class TestPyosmiumGetChanges:
         monkeypatch.setattr(osmium.replication.server.requests.Session, "get", mock_get)
 
 
-    @pytest.fixture
-    def mock_urllib(self, monkeypatch):
-        def mock_get(_, url, **kwargs):
-            return BytesIO(self.urls[url.get_full_url()])
-        monkeypatch.setattr(self.script['urlrequest'].OpenerDirector, "open", mock_get)
-
-
     def url(self, url, result):
         self.urls[url] = dedent(result).encode()
 
@@ -67,7 +60,7 @@ class TestPyosmiumGetChanges:
 
         output = capsys.readouterr().out.strip()
 
-        assert output == '454'
+        assert output == '453'
 
 
     def test_init_date(self, capsys, mock_requests):
@@ -85,14 +78,14 @@ class TestPyosmiumGetChanges:
 
         output = capsys.readouterr().out.strip()
 
-        assert output == '1'
+        assert output == '-1'
 
 
     def test_init_to_file(self, tmp_path):
         fname = tmp_path / 'db.seq'
 
         assert 0 == self.main('-I', '453', '-f', str(fname))
-        assert fname.read_text() == '454'
+        assert fname.read_text() == '453'
 
 
     def test_init_from_seq_file(self, tmp_path):
@@ -100,10 +93,10 @@ class TestPyosmiumGetChanges:
         fname.write_text('453')
 
         assert 0 == self.main('-f', str(fname))
-        assert fname.read_text() == '454'
+        assert fname.read_text() == '453'
 
 
-    def test_init_date_with_cookie(self, capsys, tmp_path, mock_urllib):
+    def test_init_date_with_cookie(self, capsys, tmp_path, mock_requests):
         self.url('https://planet.osm.org/replication/minute//state.txt',
                  """\
                     sequenceNumber=100
@@ -123,4 +116,4 @@ class TestPyosmiumGetChanges:
 
         output = capsys.readouterr().out.strip()
 
-        assert output == '1'
+        assert output == '-1'
